local M = {}

local storages = {{name = 'mainTank', field = 'remainingVolume', lastVolume = -1}, {name = 'mainBattery', field = 'storedEnergy', lastVolume = -1}} -- All possible storages. Any storages present on the vehicle will be managed by the script.
-- name is the name of the storage.
-- field is what determines the "fuel level" of the storage.
-- lastVolume is to be ignored, but still included predefined as -1.
local presentStorages = {}
local scheduleFuelSet = false
local loaded = false

local function onInit()
    loaded = false
    
    -- Attempt to find valid storages based on the defined list
    for _, storage in ipairs(storages) do
        local storageRef = energyStorage.getStorage(storage.name)
        if storageRef then
            presentStorages[storage.name] = storageRef
        end
    end
end

local function onReset()
    if not loaded then return end
    
    -- Store the remaining volumes or energy from all present storages
    for _, storage in ipairs(storages) do
        local storageRef = presentStorages[storage.name]
        if storageRef then
            storage.lastVolume = storageRef[storage.field] -- Set the lastVolume using the correct field
        end
    end
    scheduleFuelSet = true
end

local function onUpdate()
    if scheduleFuelSet then
        -- Print fuel info for debugging
        for _, storage in ipairs(storages) do
            local storageRef = presentStorages[storage.name]
            if storageRef then
                storageRef["set" .. storage.field:sub(1, 1):upper() .. storage.field:sub(2)](storageRef, storage.lastVolume)
            end
        end
        scheduleFuelSet = false
    end
    
    loaded = true
end

M.onInit = onInit
M.onReset = onReset
M.updateGFX = onUpdate

return M